@@ -1,3 +1,4 @@
+import socket
 import types
 
 
@@ -17,9 +18,9 @@ class ChannelHandler(object):
         self.channel = channel
 
     def on_error(self, exc_value, *args, **kwargs):
-        # TODO: looking at ensure() it sounds like
-        # we are ignoring any error, is this intentional?
-        pass
+        # re-raise socket timeouts to exit `ensure`
+        if isinstance(exc_value, socket.timeout):
+            raise
 
     def __call__(self, func, *args, **kwargs):
         return self.ensure(func)(*args, **kwargs)
